@@ -345,6 +345,7 @@ void Phreeqc::init(void)
 	/*----------------------------------------------------------------------
 	*   Irreversible reaction
 	*---------------------------------------------------------------------- */
+	run_cells_one_step = false;
 	// auto Rxn_reaction_map;
 	/*----------------------------------------------------------------------
 	*   Gas phase
@@ -1232,6 +1233,7 @@ Phreeqc::InternalCopy(const Phreeqc *pSrc)
 	*   Irreversible reaction
 	*---------------------------------------------------------------------- */
 	Rxn_reaction_map = pSrc->Rxn_reaction_map;
+	run_cells_one_step = pSrc->run_cells_one_step;
 	/*----------------------------------------------------------------------
 	*   Gas phase
 	*---------------------------------------------------------------------- */
